# Spoffy

The IDE friendly sync and async `Spotify API`_ wrapper for python.

Read the docs: https://spoffy.readthedocs.io


# Install

```
pip install spoffy
```
Python3.6 and newer are supported



